| Title: | Analyze Forest Diversity and Dynamics |
|---|---|
| Description: | To help you access, transform, analyze, and visualize ForestGEO data, we developed a collection of R packages (<https://forestgeo.github.io/fgeo/>). This package, in particular, helps you to install and load the entire package-collection with a single R command, and provides convenient ways to find relevant documentation. Most commonly, you should not worry about the individual packages that make up the package-collection as you can access all features via this package. To learn more about ForestGEO visit <http://www.forestgeo.si.edu/>. |
| Authors: | Mauro Lepore [aut, ctr, cre] (ORCID: <https://orcid.org/0000-0002-1986-7988>), Gabriel Arellano [aut, rev], Richard Condit [aut], Stuart Davies [aut, rev], Matteo Detto [aut], Erika Gonzalez-Akre [aut, rev] (ORCID: <https://orcid.org/0000-0001-8305-6672>), Pamela Hall [aut], Kyle Harms [aut], Valentine Herrmann [aut, rev] (ORCID: <https://orcid.org/0000-0002-4519-481X>), Aaron Hogan [rev] (ORCID: <https://orcid.org/0000-0001-9806-3074>), Bier Kraichak [rev], David Kenfack [aut, rev], Lauren Krizel [rev], Suzanne Lao [aut, rev], Sean McMahon [aut, rev], Haley Overstreet [rev], Sabrina Russo [aut, rev], Cara Scalpone [rev] (ORCID: <https://orcid.org/0000-0001-8448-2147>), Kristina Anderson-Teixeira [aut, rev], Graham Zemunik [aut, rev], Daniel Zuleta [aut, rev], CTFS-ForestGEO [cph, fnd] |
| Maintainer: | Mauro Lepore <[email protected]> |
| License: | GPL-3 |
| Version: | 1.1.4.9000 |
| Built: | 2026-05-17 06:13:51 UTC |
| Source: | https://github.com/forestgeo/fgeo |
Load fgeo's URLs into an HTML browser.
fgeo_browse() fgeo_browse_reference()fgeo_browse() fgeo_browse_reference()
Other functions to explore fgeo: fgeo_help,
fgeo_packages
if (interactive()) { fgeo_browse() fgeo_browse_reference() }if (interactive()) { fgeo_browse() fgeo_browse_reference() }
fgeo_help() finds all fgeo help files. You can refine
your search directly on the viewer panel of RStudio or via a string passed
as the first argument to fgeo_help().
fgeo_help(pattern = "", package = NULL, rebuild = TRUE, ...)fgeo_help(pattern = "", package = NULL, rebuild = TRUE, ...)
pattern |
A character string to be matched in the name, alias or title of a topic's documentation. Defaults to matching everything, which retrieves all the documentation of fgeo packages. |
package |
A character string giving the name of one or more
packages to limit the search, or |
rebuild |
a logical indicating whether the help database should
be rebuilt. This will be done automatically if |
... |
Other arguments passed to |
The results are returned in a list object of class "hsearch", which has a print method for nicely formatting the results of the query.
Other functions to explore fgeo: fgeo_browse,
fgeo_packages
if (interactive()) { fgeo_help() } dplyr::as_tibble(fgeo_help()$matches) if (interactive()) { fgeo_help("stem", package = "fgeo.x") }if (interactive()) { fgeo_help() } dplyr::as_tibble(fgeo_help()$matches) if (interactive()) { fgeo_help("stem", package = "fgeo.x") }
Names of the core fgeo packages.
fgeo_packages(include_self = TRUE)fgeo_packages(include_self = TRUE)
include_self |
Logical. Should the output include fgeo? |
A string.
Other functions to explore fgeo: fgeo_browse,
fgeo_help
fgeo_packages() fgeo_packages(include_self = FALSE)fgeo_packages() fgeo_packages(include_self = FALSE)